@@ -6,7 +6,7 @@ const CHUNK_RAW: &[u8] = include_bytes!("../resources/chunk.nbt");
 pub fn fastnbt_benchmark(c: &mut Criterion) {
     c.bench_function("chunk", |b| {
         b.iter(|| {
-            let chunk: JavaChunk = fastnbt::de::from_bytes(CHUNK_RAW).unwrap();
+            let chunk = JavaChunk::from_bytes(CHUNK_RAW).unwrap();
             black_box(chunk);
         });
     });
