@@ -1,5 +1,4 @@
 use crate::JavaChunk;
-use fastnbt::error::Result;
 
 const UNICODE_CHUNK: &[u8] = include_bytes!("../../resources/unicode.chunk");
 
@@ -9,6 +8,6 @@ fn unicode_chunk() {
     // Characters off this plane are encoded in a modified form of cesu8 which
     // is an encoding for unicode. Rust uses utf-8 for strings so there can be
     // conflicts if not deserialized properly.
-    let c: Result<JavaChunk> = fastnbt::de::from_bytes(UNICODE_CHUNK);
+    let c = JavaChunk::from_bytes(UNICODE_CHUNK);
     assert!(c.is_ok());
 }
